/***********************************************************************************
*
* Copyright © 2017-2019 STMicroelectronics - All Rights Reserved
*
* License terms: STMicroelectronics Proprietary in accordance with licensing
* terms SLA0089 at www.st.com
*
* THIS SOFTWARE IS DISTRIBUTED "AS IS," AND ALL WARRANTIES ARE DISCLAIMED,
* INCLUDING MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*
* EVALUATION ONLY – NOT FOR USE IN PRODUCTION
************************************************************************************/

/* Extended registers for DP83848 */

#ifndef __DP83848_H__
#define __DP83848_H__

#include <phydev_if.h>

uint32_t dp83848_phydev_init(phydev_ops_t * ops);

/* name PHY Status Register */ 									/* dp83843 */
#define DP83843_PHYSTS                                0x10
#define DP83843_PHYSTS_LINK_STATUS                    (1<<0)
#define DP83843_PHYSTS_SPEED_STATUS                   (1<<1)
#define DP83843_PHYSTS_DUPLEX_STATUS                  (1<<2)
#define DP83843_PHYSTS_LOOPBACK_STATUS                (1<<3)
#define DP83843_PHYSTS_RESET_STATUS              	  (1<<4)
#define DP83843_PHYSTS_AUTO_NEG_COMPLETE              (1<<5)
#define DP83843_PHYSTS_JABBER_DETECT                  (1<<6)
#define DP83843_PHYSTS_RF              				  (1<<7)
#define DP83843_PHYSTS_DP83848_INTERRUPT              (1<<8)
#define DP83843_PHYSTS_AUTO_NEG_EN               	  (1<<9)
#define DP83843_PHYSTS_PAGE_RECEIVED                  (1<<10)
#define DP83843_PHYSTS_RDY      					  (1<<11)
#define DP83843_PHYSTS_FALSE_CARRIER_SENSE_LATCH      (1<<13)
#define DP83843_PHYSTS_CARRIER_INTEGRITY_MON_LATCH    (1<<14)
#define DP83843_PHYSTS_RECEIVE_ERROR_LATCH			  (1<<15)

/* name MII Interrupt Ctrl Register. */
#define DP83843_MIPSCR                                0x11
#define DP83843_MIPSCR_TEST_INT                       (1<<0)
#define DP83843_MIPSCR_INT_EN                         (1<<1)

/* name MII Interrupt Status Register. */
#define DP83843_MIPGSR                                0x12
#define DP83843_MIPGSR_MII_INT						  (1<<15)

/* name Disconnect Counter Register. */
#define DP83843_DCR                                   0x12
#define DP83843_DCR_DCNT						  	  0xFFFF

/* name False Carrier Sense Counter Register. */
#define DP83843_FCSCR                                 0x14
#define DP83843_FCSCR_FCSCNT                          0xFFFF

/* name Receiver Error Counter Register. */
#define DP83843_RECR                                  0x15
#define DP83843_RECR_RXERCNT                          0xFFFF

/* name 100 Mb/s PCS Configuration and Status Register */
#define DP83843_PCSR                                  0x16
#define DP83843_PCSR_TX_PATTERN						  0x0180
#define DP83843_PCSR_PKT_ERR					      (1<<0)
#define DP83843_PCSR_LINK_ERR						  (1<<1)
#define DP83843_PCSR_PME_ERR                      	  (1<<2)
#define DP83843_PCSR_CODE_ERR						  (1<<3)
#define DP83843_PCSR_CARRIER_INTEGRITY_MON_STATUS	  (1<<4)
#define DP83843_PCSR_CARRIER_INTEGRITY_MON_DIS		  (1<<5)	// (Strap)
#define DP83848_PCSR_FORCE_100_OK					  (1<<6)
#define DP83843_PCSR_TX_PATTERN_0					  (1<<7)
#define DP83843_PCSR_TX_PATTERN_1					  (1<<8)
#define DP83843_PCSR_TQ_EN                     		  (1<<9)
#define DP83843_PCSR_LD_SCR_SEED                      (1<<10)
#define DP83843_PCSR_DESC_TIME_DIS					  (1<<11)
#define DP83843_PCSR_DESC_TIME						  (1<<12)
#define DP83843_PCSR_DESC_TIME_RST					  (1<<13)
#define DP83843_PCSR_FAR_END_FAULT_EN				  (1<<14) 	// (Strap)
#define DP83843_PCSR_SD_OPTION						  (1<<15)


/* name RMII and Bypass Register */
#define DP83843_LBR                                   0x17
#define DP83843_LBR_100_DP_CTL						  0x0380
#define DP83843_LBR_10Mb_ENDEC_LOOPBACK				  (1<<4)
#define DP83843_LBR_TWISTER_LOOPBACK_EN				  (1<<5)
#define DP83843_LBR_100_DP_CTL_0					  (1<<7)	// (Strap)
#define DP83843_LBR_100_DP_CTL_1					  (1<<8)	// (Strap)
#define DP83843_LBR_100_DP_CTL_2					  (1<<9)	// (Strap)
#define DP83843_LBR_BYPASS_TX						  (1<<10)	// (Strap)
#define DP83843_LBR_BYPASS_RX						  (1<<11)	// (Strap)
#define DP83843_LBR_BYPASS_SCR						  (1<<12)	// (Strap)
#define DP83843_LBR_BYPASS_4B5B						  (1<<13)	// (Strap)
#define DP83843_LBR_BYPASS_LED_STRETCH				  (1<<14)	// (Strap)

/* name LED Direct Control Register */
#define DP83843_10BTSCR                         	  0x18
#define DP83843_10BTSCR_RX_FILT_DIS		              (1<<2)
#define DP83843_10BTSCR_THIN_SEL		              (1<<3)
#define DP83843_10BTSCR_JABBER_DIS                    (1<<4)
#define DP83843_10BTSCR_AUI_SEL                       (1<<5)
#define DP83843_10BTSCR_LOW_SQUELCH_SEL				  (1<<6)
#define DP83843_10BTSCR_HEARTBEAT_DIS				  (1<<7)
#define DP83843_10BTSCR_LP_DIS						  (1<<8)
#define DP83843_10BTSCR_AUTOSW_EN					  (1<<9)
#define DP83843_10BTSCR_POLARITY_DIS				  (1<<10)
#define DP83843_10BTSCR_TX_SERIAL					  (1<<11)	// (strap)
#define DP83843_10BTSCR_RX_SERIAL					  (1<12)	// (strap)
#define DP83843_10BTSCR_AUI_TPI						  (1<13)

/* name PHY Control Register */
#define DP83843_PHYCR                                 0x19
#define DP83843_PHYCR_PHYADDR                         0x001F
#define DP83843_PHYCR_LED_TXRX_MODE					  0x0180
#define DP83843_PHYCR_TWISTER_EQ_SEL				  0x3000
#define DP83843_PHYCR_FX_EN							  (1<<5)	// (strap)
#define DP83843_PHYCR_LED_DUPLEX_MODE				  (1<<6)
#define DP83843_PHYCR_LED_TXRX_MODE_0				  (1<<7)
#define DP83843_PHYCR_LED_TXRX_MODE_1                 (1<<8)
#define DP83843_PHYCR_REPEATER_MODE                   (1<<9)	// (strap)
#define DP83843_PHYCR_TWISTER_BLW_DIS                 (1<<11)
#define DP83843_PHYCR_TWISTER_EQ_SEL_0                (1<<12)
#define DP83843_PHYCR_TWISTER_EQ_DEL_1                (1<<13)

#endif				/* __DP83848_H__ */
